
penman.exceptions
=================

.. automodule:: penman.exceptions

   .. autoexception:: PenmanError
      :members:

   .. autoexception:: ConstantError
      :show-inheritance:
      :members:

   .. autoexception:: GraphError
      :show-inheritance:
      :members:

   .. autoexception:: LayoutError
      :show-inheritance:
      :members:

   .. autoexception:: DecodeError
      :show-inheritance:
      :members:

   .. autoexception:: SurfaceError
      :show-inheritance:
      :members:

   .. autoexception:: ModelError
      :show-inheritance:
      :members:
